@@ -72,7 +72,7 @@ BOOL nt_init_board_menu()
 	}
 
 
-	if(!nt_http_get(url, outp, NULL, NULL, NULL, FALSE)){
+	if(!nt_http_get(url, outp, NULL, NULL, NULL, FALSE, FALSE)){
 		free(outp);
 		return FALSE;
 	}
@@ -118,7 +118,7 @@ BOOL nt_init_board_menu()
 	return TRUE;
 }
 
-BOOL nt_read_thread(nt_2ch_model_tp modelp)
+BOOL nt_read_thread(nt_2ch_selected_item_tp selectp)
 {
 	wchar_t url[1024];
 	wchar_t referer[1024];
@@ -140,15 +140,15 @@ BOOL nt_read_thread(nt_2ch_model_tp modelp)
 	memset(s_dst, '\0', sizeof(s_dst));
 
 
-	if(!modelp->selected_categoryp)
+	if(!selectp->selected_categoryp)
 		return FALSE;
-	if(!modelp->selected_boardp)
+	if(!selectp->selected_boardp)
 		return FALSE;
-	if(!modelp->selected_threadp)
+	if(!selectp->selected_threadp)
 		return FALSE;
 
-	boardp = modelp->selected_boardp;
-	threadp = modelp->selected_threadp;
+	boardp = selectp->selected_boardp;
+	threadp = selectp->selected_threadp;
 	file_name = threadp->file_name;
 
 	wcscpy(url, boardp->address);
@@ -189,13 +189,13 @@ BOOL nt_read_thread(nt_2ch_model_tp modelp)
 		return	FALSE;
 	}
 
-	if(!nt_http_get(s_src, outp, s_dst, NULL, NULL, TRUE)){
+	if(!nt_http_get(s_src, outp, s_dst, NULL, NULL, TRUE, FALSE)){
 		if(!set_offlaw_address(s_src, sizeof(s_src),
 				server_name, board_name, file_name)){
 			free(outp);
 			return FALSE;
 		}
-		if(!nt_http_get(s_src, outp, s_dst, NULL, NULL, FALSE)){
+		if(!nt_http_get(s_src, outp, s_dst, NULL, NULL, FALSE, FALSE)){
 			free(outp);
 			return FALSE;
 		}
@@ -314,7 +314,7 @@ wchar_t* nt_read_thread_title(nt_board_tp boardp,
 	return title;
 }
 
-BOOL nt_read_board(nt_2ch_model_tp modelp)
+BOOL nt_read_board(nt_2ch_selected_item_tp selectp)
 {
 	wchar_t *address;
 	char data[256+1];
@@ -331,12 +331,12 @@ BOOL nt_read_board(nt_2ch_model_tp modelp)
 	memset(s_src, '\0', S_SIZE);
 	memset(s_dst, '\0', S_SIZE*sizeof(wchar_t));
 
-	if(!modelp->selected_categoryp)
+	if(!selectp->selected_categoryp)
 		return FALSE;
-	if(!modelp->selected_boardp)
+	if(!selectp->selected_boardp)
 		return FALSE;
 
-	boardp = modelp->selected_boardp;
+	boardp = selectp->selected_boardp;
 	nt_board_children_free(boardp);
 	address = boardp->address;
 	assert(address);
@@ -354,7 +354,7 @@ BOOL nt_read_board(nt_2ch_model_tp modelp)
 		return	FALSE;
 	}
 
-	if(!nt_http_get(data, outp, URL_2CH_BOARDMENU, NULL, NULL, FALSE)){
+	if(!nt_http_get(data, outp, URL_2CH_BOARDMENU, NULL, NULL, FALSE, FALSE)){
 		free(outp);
 		return FALSE;
 	}
@@ -398,7 +398,7 @@ BOOL nt_read_board(nt_2ch_model_tp modelp)
 	return TRUE;
 }
 
-BOOL nt_write_msg(nt_2ch_model_tp modelp, nt_write_data_tp writep,
+BOOL nt_write_msg(nt_2ch_selected_item_tp selectp, nt_write_data_tp writep,
 			nt_cookie_tp cookiep, nt_maru_2ch_tp marup)
 {
 	wchar_t	url[1024];	
@@ -421,17 +421,15 @@ BOOL nt_write_msg(nt_2ch_model_tp modelp, nt_write_data_tp writep,
 	memset(s_dst,	'\0',	sizeof(s_dst));
 	memset(post_data,	'\0',	sizeof(post_data));
 
-	assert(modelp);
-
-	if(!modelp->selected_categoryp)
+	if(!selectp->selected_categoryp)
 		return	FALSE;
-	if(!modelp->selected_boardp)
+	if(!selectp->selected_boardp)
 		return	FALSE;
-	if(!modelp->selected_threadp)
+	if(!selectp->selected_threadp)
 		return	FALSE;
 
-	boardp = modelp->selected_boardp;
-	threadp = modelp->selected_threadp;
+	boardp = selectp->selected_boardp;
+	threadp = selectp->selected_threadp;
 	file_name = threadp->file_name;
 
 	if(!nt_parse_server_name_and_board_name(boardp->address,
