@@ -23,7 +23,7 @@
 #include "html/html_string.h"
 #include "_2ch/model_2ch.h"
 
-extern void nt_set_selected_board(nt_2ch_selected_item_tp selectp,
+void nt_set_selected_board(nt_2ch_selected_item_tp selectp,
          nt_category_tp categoryp, nt_board_tp boardp)
 {
 	assert(selectp);
@@ -35,7 +35,7 @@ extern void nt_set_selected_board(nt_2ch_selected_item_tp selectp,
 	selectp->selected_threadp = NULL;
 }
 
-extern void nt_set_selected_thread(nt_2ch_selected_item_tp selectp,
+void nt_set_selected_thread(nt_2ch_selected_item_tp selectp,
         nt_thread_tp threadp)
 {
 	assert(selectp);
