@@ -84,17 +84,20 @@ wchar_t* nt_w_format_number_list (nt_link_tp num_listp)
 		}else if(num == prev_num+1){
 			if(s_num < 0)
 				s_num = prev_num;
-		}else{
+		}else if(prev_num != -1){
 			if(s_num < 0){
 				if(len == 0)
-					ret = swprintf(buf, buf_size, L"%d", num);
+					ret = swprintf(buf, buf_size, L"%d", prev_num);
 				else
-					ret = swprintf(buf+len, buf_size-len, L",%d", num);
+					ret = swprintf(buf+len, buf_size-len, L",%d", prev_num);
 			}else{
 				if(len == 0)
-					ret = swprintf(buf, buf_size, L"%d-%d", num);
+					ret = swprintf(buf, buf_size, 
+								L"%d-%d", s_num, prev_num);
 				else
-					ret = swprintf(buf+len, buf_size-len, L",%d-%d", num);
+					ret = swprintf(buf+len, buf_size-len, 
+								L",%d-%d", s_num, prev_num);
+				s_num = -1;
 			}
 			if(ret < 0){
 				free(buf);
@@ -108,9 +111,28 @@ wchar_t* nt_w_format_number_list (nt_link_tp num_listp)
 				buf_size += delta;
 			}
 		}
+		prev_num = num;
 		linkp = linkp->next;
 	}while(linkp != num_listp);
-	
+	if(prev_num != -1){
+		if(s_num < 0){
+			if(len == 0)
+				ret = swprintf(buf, buf_size, L"%d", prev_num);
+			else
+				ret = swprintf(buf+len, buf_size-len, L",%d", prev_num);
+		}else{
+			if(len == 0)
+				ret = swprintf(buf, buf_size, 
+							L"%d-%d", s_num, prev_num);
+			else
+				ret = swprintf(buf+len, buf_size-len, 
+							L",%d-%d", s_num, prev_num);
+		}
+		if(ret < 0){
+			free(buf);
+			return NULL;
+		}
+	}
 	return buf;
 }
 
