@@ -54,12 +54,9 @@ typedef struct tag_nt_res_t{
 
 typedef struct tag_nt_2ch_model_t *nt_2ch_model_tp;
 typedef struct tag_nt_2ch_model_t{
+	
 	nt_link_tp categorylistp;
-
-	nt_category_tp selected_categoryp;
-	nt_board_tp selected_boardp;
-	nt_thread_tp selected_threadp;
-
+	
 } nt_2ch_model_t;
 
 typedef struct tag_nt_write_data_t *nt_write_data_tp;
@@ -73,6 +70,15 @@ typedef struct tag_nt_write_data_t
 	nt_link_tp cookies;
 } nt_write_data_t;
 
+
+typedef struct tag_nt_2ch_selected_item_t *nt_2ch_selected_item_tp;
+typedef struct tag_nt_2ch_selected_item_t{
+	nt_category_tp selected_categoryp;
+	nt_board_tp selected_boardp;
+	nt_thread_tp selected_threadp;
+}nt_2ch_selected_item_t;
+
+
 extern nt_write_data_tp nt_write_data_alloc();
 extern void nt_write_data_free(nt_write_data_tp ptr);
 
@@ -87,7 +93,10 @@ extern nt_thread_tp nt_thread_alloc(
 extern nt_res_tp nt_res_alloc(nt_thread_tp	threadp, 
 		const wchar_t *name, const wchar_t *mail, 
 		const wchar_t *misc, const wchar_t *msg);
-
+extern nt_board_tp nt_get_board_by_name(
+		nt_2ch_model_tp modelp, const wchar_t *board_name, nt_category_tp *categorypp);
+extern nt_board_tp nt_get_board_by_address_match(
+		nt_2ch_model_tp modelp, const wchar_t *param);
 extern void nt_2ch_model_free(nt_2ch_model_tp ptr);
 extern void nt_category_free(nt_category_tp ptr);
 extern void nt_board_free(nt_board_tp ptr);
@@ -101,9 +110,10 @@ extern BOOL parse_board_menu(nt_2ch_model_tp modelp,
 extern BOOL parse_board(nt_board_tp boardp, const wchar_t *linep);
 extern BOOL parse_thread(nt_thread_tp boardp, const wchar_t *linep);
 
-extern void nt_set_selected_board(nt_2ch_model_tp modelp,
+extern void nt_set_selected_board(nt_2ch_selected_item_tp selectp,
 		nt_category_tp categoryp, nt_board_tp boardp);
-extern void nt_set_selected_thread(nt_2ch_model_tp modelp, nt_thread_tp threadp);
+extern void nt_set_selected_thread(
+		nt_2ch_selected_item_tp selectp, nt_thread_tp threadp);
 
 extern nt_thread_tp nt_get_thread_by_seq_no(
 		nt_link_tp thread_list, int seq_no);
