@@ -23,5 +23,11 @@
 #define NT_ERR_MSG_WRITE_MSG_ABORTED (L"中止しました")
 #define NT_ERR_MSG_REFRESH_THREAD_FAILED (L"スレッドの更新に失敗しました")
 #define NT_ERR_MSG_SEARCH_NOT_FOUND (L"文字列が見つかりませんでした")
+#define NT_ERR_MSG_ADD_FAVORITE_FAILED (L"お気に入りに追加出来ませんでした")
+#define NT_ERR_MSG_DEL_FAVORITE_FAILED (L"お気に入りから削除出来ませんでした")
+
+#define NT_ERR_MSG_MEMORY_ALLOCATION (L"メモリーの割り当てに失敗しました")
+
+#define NT_ERR_MSG_THREAD_POOL_PARAM (L"スレッドプールの初期化引数が不正です")
 
 #endif /*_ERROR_H_*/
