@@ -21,10 +21,11 @@
 #include "env.h"
 
 #ifdef HAVE_NDBM_H 
-#define GDBM_COMPT
 #include <ndbm.h>
 #elif HAVE_GDBM_NDBM_H
 #include <gdbm-ndbm.h>
+#else
+#include <ndbm.h>
 #endif
 
 
