@@ -567,6 +567,11 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle,
 		case KEY_LEFT:
 			wclear(scrp);
 			break;
+		case KEY_HOME:
+			ch = NT_KEY_COMMAND1;
+			nt_add_wch(scrp,ch,0);
+			strncpy(buf,"1",2);
+			break;
 		case NT_KEY_COMMAND1:
 		case NT_KEY_COMMAND2:
 		case NT_KEY_COMMAND3:
