@@ -35,6 +35,7 @@
 
 #define NT_CMD_NONE 0
 #define NT_CMD_SEARCH_THREAD 1
+#define NT_CMD_FAVORITE 2
 
 
 typedef struct tag_category_data_t *category_data_tp;
@@ -85,13 +86,17 @@ int disp_board_menu(nt_window_tp wp,
 	int i;
 	int offset_y, offset_x;
 	BOOL selected = FALSE;
+	BOOL add_favorite = FALSE;
 	int cmd;
+	int result_state;
 
 	wchar_t *cname;
 	attr_t attr;
 
 	assert(modelp);
 	assert(wp);
+	
+	result_state = DISP_STATE_BOARDMENU;
 
 	ctxp = (ctx_board_menu_tp)wp->data;
 	if(!ctxp){
@@ -129,22 +134,29 @@ int disp_board_menu(nt_window_tp wp,
 	case KEY_RIGHT:
 		selected = TRUE;
 		break;
+	//case NT_KEY_DEL:
+	//	fprintf(stderr, "check in\n");
+	case NT_KEY_ADD:
+		add_favorite = TRUE;
+		break;
 	case NT_KEY_COMMAND1:
 		assert(wp->cmd_param);
 		cmd = parse_cmd1(wp->cmd_param);
 		switch(cmd){
 		case NT_CMD_SEARCH_THREAD:
 			return DISP_STATE_SEARCH_THREAD;
+		case NT_CMD_FAVORITE:
+			return DISP_STATE_FAVORITE;
 		}
 	}
 
 	clistp = modelp->categorylistp;
 	if(clistp == NULL)
-		return TRUE;
+		return DISP_STATE_ERROR;
 	for(i = 0; i < ctxp->category_num; i++){
 		offset_y = cur_line - ctxp->scroll_pos;
 		if(offset_y == (wp->lines*2)){
-			return TRUE;
+			return result_state;
 		}else if(offset_y >= wp->lines){
 			offset_y -= wp->lines;
 			offset_x = wp->cols / 2;
@@ -186,18 +198,22 @@ int disp_board_menu(nt_window_tp wp,
 			continue;
 		sel_boardp = NULL;
 		if(!disp_board(wp, ctxp, &cur_line, categoryp,
-					selected, &sel_boardp))
-			return FALSE;
+					(selected | add_favorite), &sel_boardp))
+			return DISP_STATE_ERROR;
 		if(selected && sel_boardp){
 			nt_set_selected_board(selectp, categoryp, sel_boardp);
 			return DISP_STATE_THREADTITLE;
+		}else if(add_favorite && sel_boardp){
+			nt_set_selected_board(selectp, categoryp, sel_boardp);
+			result_state |= DISP_CMD_ADD_FAVORITE;
+			add_favorite = FALSE;
 		}
 	}
 
 	touchwin(wp->wp);
 	wrefresh(wp->wp);
 
-	return DISP_STATE_BOARDMENU;
+	return result_state;
 }
 
 static BOOL disp_board(nt_window_tp wp, ctx_board_menu_tp ctxp,
@@ -231,7 +247,7 @@ static BOOL disp_board(nt_window_tp wp, ctx_board_menu_tp ctxp,
 		if(*cur_line == ctxp->cursor_pos){
 			if(selected){
 				*sel_boardpp = (nt_board_tp)blist_tmp->data;
-				return TRUE;
+				//return TRUE;
 			}
 			attr = WA_REVERSE;
 		}else{
@@ -474,6 +490,11 @@ static int parse_cmd1(const char *param)
 		0 == strncmp(NT_COMMAND1_SEARCH_2,param,
 			strlen(NT_COMMAND1_SEARCH_2))){
 		return NT_CMD_SEARCH_THREAD;
+	}else if(0 == strncmp(NT_COMMAND1_FAVORITE_1,param,
+			strlen(NT_COMMAND1_FAVORITE_1)) ||
+		0 == strncmp(NT_COMMAND1_FAVORITE_2,param,
+			strlen(NT_COMMAND1_FAVORITE_2))){
+		return NT_CMD_FAVORITE;
 	}else{
 		return NT_CMD_NONE;
 	}
