@@ -62,6 +62,7 @@ typedef struct tag_ctx_threadlist_t
 #define NT_CMD_SORT_UNREAD 3
 #define NT_CMD_DEL_THREAD_LOG 4
 #define NT_CMD_SEARCH_THREAD 5
+#define NT_CMD_FAVORITE 6
 
 static int parse_cmd1(const char *param);
 static int get_thread_index_by_seqno(nt_link_tp linkp, int seq_no);
@@ -111,7 +112,10 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 	int cmd;
 	BOOL sort;
 	const char *start, *end;
+	char *cptr;
+	int result_state;
 
+	result_state = DISP_STATE_THREADTITLE;
 	sort = FALSE;
 
 	ctxp = (ctx_threadlist_tp)wp->data;
@@ -214,14 +218,18 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 			case NT_CMD_DEL_THREAD_LOG: 
 				if(!nt_strtok(wp->cmd_param,' ', &start, &end))
 					break;
-
-				if(0 == strcmp("*", end)){
+				cptr = nt_trim(end);
+				if(!cptr)
+					break;
+				if(0 == strcmp("*", cptr)){
+					free(cptr);
 					if(!nt_usr_db_delete_board_log(db_handle,
 							boardp->name))
 						break;
 					return DISP_STATE_REFRESH;
 				}
-				linkp = nt_parse_number_list(end, NULL);
+				linkp = nt_parse_number_list(cptr, NULL);
+				free(cptr);
 				if(!linkp)
 					break;
 				clistp = linkp;
@@ -245,6 +253,8 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 				return DISP_STATE_REFRESH;
 			case NT_CMD_SEARCH_THREAD:
 				return DISP_STATE_SEARCH_THREAD;
+			case NT_CMD_FAVORITE:
+				return DISP_STATE_FAVORITE;
 			default:
 				break;
 			}
@@ -343,6 +353,13 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 			break;
 		nt_set_selected_thread(selectp, threadp);
 		return DISP_STATE_RESLIST;
+	case NT_KEY_ADD:
+		threadp = nt_link_get_by_index(ctxp->thread_disp_list,
+				ctxp->cursor_pos);
+		if(!threadp)
+			break;
+		nt_set_selected_thread(selectp, threadp);
+		result_state |= DISP_CMD_ADD_FAVORITE;
 	}
 
 	clistp = ctxp->thread_disp_list;
@@ -414,7 +431,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 		clistp = clistp->next;
 	}/* end for */
 	
-	return DISP_STATE_THREADTITLE; 
+	return result_state; 
 }
 
 static ctx_threadlist_tp init_context(nt_2ch_selected_item_tp selectp)
@@ -655,6 +672,11 @@ static int parse_cmd1(const char *param)
 		0 == strncmp(NT_COMMAND1_SEARCH_2,param,
 			strlen(NT_COMMAND1_SEARCH_2))){
 		return NT_CMD_SEARCH_THREAD;
+	}else if(0 == strncmp(NT_COMMAND1_FAVORITE_1,param,
+			strlen(NT_COMMAND1_FAVORITE_1)) ||
+		0 == strncmp(NT_COMMAND1_FAVORITE_2,param,
+			strlen(NT_COMMAND1_FAVORITE_2))){
+		return NT_CMD_FAVORITE;
 	}else if(0 == strncmp(NT_COMMAND1_SORT_1, param,
 			strlen(NT_COMMAND1_SORT_1))){
 		offset = strlen(NT_COMMAND1_SORT_1);
