@@ -68,11 +68,21 @@ static const char *NT_SQL_INSERT_READ_CNT =
 	"VALUES (1, :res_no, :board_name, :dat_name, "
 	"julianday(\'now\') )"; 
 
+static const char *NT_SQL_DELETE_BOARD_LOG =
+	"DELETE FROM usr_log WHERE "
+	"board_name = :board_name ";
+
+static const char *NT_SQL_DELETE_THREAD_LOG =
+	"DELETE FROM usr_log WHERE "
+	"board_name = :board_name AND dat_name = :dat_name ";
+
 static BOOL usr_tbl_create(sqlite3 *dbp);
 static int usr_tbl_validate(sqlite3 *dbp);
 
 static nt_usr_db_thread_data_tp
 	thread_data_alloc(int read_count, const wchar_t *dat_name);
+static BOOL nt_remove_thread_data(nt_link_tp *thread_data,
+		const wchar_t *dat_name);
 
 /* 
  * Initialize the Sqlite library.
@@ -374,6 +384,167 @@ ERROR_TRAP:
 	return result;
 }
 
+BOOL nt_usr_db_delete_board_log(void *db_handle,
+	const wchar_t *board_name)
+{
+	int len;
+	int rc , idx;
+	ctx_usr_db_tp ctxp;
+	char board_nm_buf[256];
+	sqlite3_stmt *stmt;
+	BOOL result;
+
+	assert(board_name);
+	assert(db_handle);
+
+	stmt = NULL;
+	result = FALSE;
+
+	ctxp = (ctx_usr_db_tp)db_handle;
+
+	len = wcstombs(board_nm_buf, board_name, sizeof(board_nm_buf));
+	if(len <= 0)
+		return FALSE;
+
+	if(!nt_usr_db_open(ctxp)){
+		return FALSE;
+	}
+
+	rc = sqlite3_prepare_v2(ctxp->dbp,
+			NT_SQL_DELETE_BOARD_LOG, -1,
+			&stmt, NULL);
+	if(rc != SQLITE_OK){
+		fputs(sqlite3_errmsg(ctxp->dbp), stderr);
+		goto ERROR_TRAP;
+	}
+	idx = sqlite3_bind_parameter_index(stmt, ":board_name");
+	if(idx == 0 ||
+		SQLITE_OK != sqlite3_bind_text(stmt, idx, 
+			board_nm_buf, -1, SQLITE_STATIC)){
+		goto ERROR_TRAP;
+	}
+
+	rc = sqlite3_step(stmt);
+	if(rc != SQLITE_DONE){
+		goto ERROR_TRAP;
+	}
+	result = TRUE;
+ERROR_TRAP:
+	if(stmt)
+	    sqlite3_finalize(stmt);
+	nt_usr_db_close(ctxp);
+	return result;
+}
+
+BOOL nt_usr_db_delete_thread_log(void *db_handle,
+	const wchar_t *board_name, const wchar_t *dat_name,
+	nt_link_tp *thread_data_list)
+{
+	int len;
+	int rc , idx;
+	ctx_usr_db_tp ctxp;
+	char board_nm_buf[256];
+	char dat_nm_buf[64];
+	sqlite3_stmt *stmt;
+	BOOL result;
+
+	assert(board_name);
+	assert(dat_name);
+	assert(db_handle);
+
+	stmt = NULL;
+	result = FALSE;
+
+	ctxp = (ctx_usr_db_tp)db_handle;
+
+	len = wcstombs(board_nm_buf, board_name, sizeof(board_nm_buf));
+	if(len <= 0)
+		return FALSE;
+
+	len = wcstombs(dat_nm_buf, dat_name, sizeof(dat_nm_buf));
+	if(len <= 0)
+		return FALSE;
+
+	if(!nt_usr_db_open(ctxp)){
+		return FALSE;
+	}
+
+	rc = sqlite3_prepare_v2(ctxp->dbp,
+			NT_SQL_DELETE_THREAD_LOG, -1,
+			&stmt, NULL);
+	if(rc != SQLITE_OK){
+		fputs(sqlite3_errmsg(ctxp->dbp), stderr);
+		goto ERROR_TRAP;
+	}
+	idx = sqlite3_bind_parameter_index(stmt, ":board_name");
+	if(idx == 0 ||
+		SQLITE_OK != sqlite3_bind_text(stmt, idx, 
+			board_nm_buf, -1, SQLITE_STATIC)){
+		goto ERROR_TRAP;
+	}
+	idx = sqlite3_bind_parameter_index(stmt, ":dat_name");
+	if(idx == 0 ||
+		SQLITE_OK != sqlite3_bind_text(stmt, idx, 
+			dat_nm_buf, -1, SQLITE_STATIC)){
+		goto ERROR_TRAP;
+	}
+
+
+	rc = sqlite3_step(stmt);
+	if(rc != SQLITE_DONE){
+		goto ERROR_TRAP;
+	}
+	if(thread_data_list &&  *thread_data_list &&
+			!nt_remove_thread_data(thread_data_list, dat_name)){
+		goto ERROR_TRAP;
+	}
+	result = TRUE;
+ERROR_TRAP:
+	if(stmt)
+	    sqlite3_finalize(stmt);
+	nt_usr_db_close(ctxp);
+	return result;
+}
+
+static BOOL nt_remove_thread_data(nt_link_tp *threadpp,
+		const wchar_t *dat_name)
+{
+	nt_link_tp threadp;
+	nt_link_tp linkp, nextp;
+	nt_usr_db_thread_data_tp datap;
+
+
+	threadp = *threadpp;
+
+	linkp = threadp->next;
+	while(linkp != threadp){
+		datap = (nt_usr_db_thread_data_tp)
+			linkp->data;
+		if(!datap){
+			linkp = linkp->next;
+			continue;
+		}
+		if(0 != wcscmp(dat_name, datap->dat_name)){
+			linkp = linkp->next;
+			continue;
+		}
+		nextp = linkp->next;
+		nt_link_remove2(threadp, linkp);
+		nt_usr_db_thread_data_free(datap);
+		free(linkp);
+		linkp = nextp;
+	}
+	datap = (nt_usr_db_thread_data_tp)
+		linkp->data;
+	if(datap && 0 == wcscmp(dat_name, datap->dat_name)){
+		*threadpp = nt_link_remove2(threadp, linkp);
+		nt_usr_db_thread_data_free(datap);
+		free(linkp);
+	}
+	return  TRUE;
+}
+
+
 /*
  * name: usr_tbl_validate
  * function: validate usr table
