@@ -383,5 +383,33 @@ BOOL nt_strtok(const char *str, char delim,
 				state = 1;
 		}
 	}
-	return TRUE;
+	return (*start < *end) ? TRUE : FALSE;
+}
+
+BOOL nt_w_strtok(const wchar_t *str, wchar_t delim,
+        const wchar_t** start, const wchar_t **end)
+{
+	int i, len, state;
+
+	assert(str);
+
+	len = wcslen(str);
+	*start = str;
+	*end = str + len;
+
+	state = 0;
+	for(i = 0; i < len; i++){
+		if(str[i] == delim){
+			if(state == 0){
+				*start = str + i + 1;
+			}else if(state == 1){
+				*end = str + i;
+				return TRUE;
+			}
+		}else{
+			if(state == 0)
+				state = 1;
+		}
+	}
+	return (*start < *end) ? TRUE : FALSE;
 }
